@@ -34,7 +34,9 @@ __all__ = (
     "PipelineExecutionStartConditionType",
     "PipelineStatusType",
     "PlatformType",
+    "imagebuilderServiceName",
     "ServiceName",
+    "ResourceServiceName",
 )
 
 
@@ -66,6 +68,7 @@ PipelineExecutionStartConditionType = Literal[
 ]
 PipelineStatusType = Literal["DISABLED", "ENABLED"]
 PlatformType = Literal["Linux", "Windows"]
+imagebuilderServiceName = Literal["imagebuilder"]
 ServiceName = Literal[
     "accessanalyzer",
     "account",
@@ -97,6 +100,7 @@ ServiceName = Literal[
     "backup",
     "backup-gateway",
     "batch",
+    "billingconductor",
     "braket",
     "budgets",
     "ce",
@@ -219,6 +223,7 @@ ServiceName = Literal[
     "kafka",
     "kafkaconnect",
     "kendra",
+    "keyspaces",
     "kinesis",
     "kinesis-video-archived-media",
     "kinesis-video-media",
@@ -367,3 +372,15 @@ ServiceName = Literal[
     "workspaces-web",
     "xray",
 ]
+ResourceServiceName = Literal[
+    "cloudformation",
+    "cloudwatch",
+    "dynamodb",
+    "ec2",
+    "glacier",
+    "iam",
+    "opsworks",
+    "s3",
+    "sns",
+    "sqs",
+]
